y0f_small_argument_path

Function y0f_small_argument_path 

fn y0f_small_argument_path(x: f32) -> f32
This method on small range searches for nearest zero or extremum. Then picks stored series expansion at the point end evaluates the poly at the point.